# tsfeast
![build](https://travis-ci.com/chris-santiago/tsfeast.svg?branch=master)
[![codecov](https://codecov.io/gh/chris-santiago/tsfeast/branch/master/graph/badge.svg?token=MSO9ZBH6UD)](https://codecov.io/gh/chris-santiago/tsfeast)

A collection of Scikit-Learn compatible time series transformers and tools.

## Installation

```bash
pip install tsfeast
```

## Documentation 

Documentation hosted on Github Pages: [https://chris-santiago.github.io/tsfeast/](https://chris-santiago.github.io/tsfeast/)